pub struct RuntimeEntryRegistryDelta {
pub added_entries: Vec<RuntimeEntryDescriptor>,
pub removed_entry_names: Vec<String>,
pub updated_entries: Vec<RuntimeEntryDescriptor>,
}Expand description
Structured entry-registry delta emitted when one reload changes exposed runtime entries. 当一次重载改变已暴露运行时入口时发出的结构化入口注册表差异。
Fields
added_entries: Vec<RuntimeEntryDescriptor>Newly added runtime entries after the latest reload. 最近一次重载后新增的运行时入口。
removed_entry_names: Vec<String>Canonical names removed after the latest reload. 最近一次重载后移除的 canonical 入口名称。
updated_entries: Vec<RuntimeEntryDescriptor>Existing canonical entries whose structure changed after the latest reload. 最近一次重载后结构发生变化的既有 canonical 入口。