pub struct RuntimeSkillLifecycleEvent {
pub plane: SkillOperationPlane,
pub action: SkillLifecycleAction,
pub skill_id: String,
pub root_name: Option<String>,
pub skill_dir: Option<String>,
pub status: String,
pub message: Option<String>,
}Expand description
Structured lifecycle event emitted after one skill-management operation is evaluated. 在评估一次技能管理操作后发出的结构化生命周期事件。
Fields
plane: SkillOperationPlaneOperation plane that triggered the lifecycle event. 触发生命周期事件的操作平面。
action: SkillLifecycleActionLifecycle action represented by the current event. 当前事件所表示的生命周期动作。
skill_id: StringSkill identifier targeted by the current lifecycle operation. 当前生命周期操作对应的技能标识符。
root_name: Option<String>Optional named skill root that owns the effective target skill instance. 拥有当前生效目标技能实例的可选命名技能根。
skill_dir: Option<String>Optional physical skill directory of the effective target skill instance. 当前生效目标技能实例的可选物理技能目录。
status: StringHigh-level event status such as completed, failed, or blocked. 当前事件的高层状态,例如 completed、failed 或 blocked。
message: Option<String>Optional human-readable explanation of the current lifecycle outcome. 当前生命周期结果的可选人类可读说明。