LuaRuntimeSpaceControllerProcessMode

Enum LuaRuntimeSpaceControllerProcessMode 

pub enum LuaRuntimeSpaceControllerProcessMode {
    Service,
    Managed,
}
Process mode used when the runtime auto-spawns one local space controller process. 运行时自动拉起本地空间控制器进程时使用的进程模式。

Variants



Service

Service mode keeps the controller process alive until an external stop happens. Service 模式会让控制器进程持续存活,直到外部显式停止。



Managed

Managed mode allows the controller process to stop itself after idle timeouts. Managed 模式允许控制器进程在空闲超时后自行停止。