pub struct RuntimeHelpNodeDescriptor {
pub flow_name: String,
pub description: String,
pub related_entries: Vec<String>,
pub is_main: bool,
}Expand description
One structured help node descriptor returned to host-side system tool wrappers. 返回给宿主侧 system tool 包装层的单个结构化帮助节点描述。
Fields
flow_name: StringStable node name. The main node always uses main.
稳定节点名称,主节点固定使用 main。
description: StringHuman-readable short description of the current help node. 当前帮助节点的人类可读简要说明。
Canonical runtime entries related to the current help node. 与当前帮助节点关联的 canonical 运行时入口列表。
is_main: boolWhether the current node is the main help node of one skill. 当前节点是否为某个 skill 的主帮助节点。