pub struct RuntimeSkillHelpDescriptor {
pub skill_id: String,
pub skill_name: String,
pub skill_version: String,
pub root_name: String,
pub skill_dir: String,
pub main: RuntimeHelpNodeDescriptor,
pub flows: Vec<RuntimeHelpNodeDescriptor>,
}Expand description
Structured help tree summary of one skill returned by the runtime core. 由运行时核心返回的单个 skill 结构化帮助树摘要。
Fields
skill_id: StringStable skill identifier of the current help tree. 当前帮助树所属的稳定 skill 标识符。
skill_name: StringHuman-readable internal skill name. 人类可读的内部 skill 名称。
skill_version: StringSemantic package version declared by the current skill. 当前技能声明的语义化包版本。
root_name: StringNamed skill root that currently owns the effective help tree. 当前生效帮助树所属的命名技能根。
skill_dir: StringPhysical skill directory that currently owns the effective help tree. 当前生效帮助树所属的物理技能目录。
main: RuntimeHelpNodeDescriptorMain help node summary. 主帮助节点摘要。
flows: Vec<RuntimeHelpNodeDescriptor>Topic/workflow help node summaries declared under the current skill. 当前 skill 声明的 topic/workflow 子帮助节点摘要。