ManagedRuntimeEnvPlan

Struct ManagedRuntimeEnvPlan 

pub struct ManagedRuntimeEnvPlan {
Show 25 fields pub runtime: ManagedRuntimeKind, pub platform: String, pub runtime_root: PathBuf, pub distribution_root: PathBuf, pub environment_root: PathBuf, pub distribution_source: ManagedRuntimeRootSource, pub environment_source: ManagedRuntimeRootSource, pub runtime_install_root: PathBuf, pub runtime_version: String, pub runtime_executable: PathBuf, pub runtime_install_manifest_hash: String, pub runtime_executable_hash: String, pub package_manager: String, pub package_manager_version: String, pub package_manager_executable: PathBuf, pub package_manager_install_root: PathBuf, pub package_manager_install_manifest_hash: String, pub package_manager_executable_hash: String, pub package_manifest_path: Option<PathBuf>, pub lockfile_path: PathBuf, pub lock_hash: String, pub package_manifest_hash: Option<String>, pub env_hash: String, pub env_dir: PathBuf, pub expected_marker: ManagedRuntimeEnvMarker, /* private fields */
}
Resolved managed runtime environment plan used before creation or invocation. 创建环境或调用前使用的受管运行时环境解析计划。

Fields

runtime: ManagedRuntimeKind

Managed runtime kind described by this plan. 当前计划描述的受管运行时类型。

platform: String

Current platform key. 当前平台键。

runtime_root: PathBuf

Canonical LuaSkills data root used for package stores, snapshots, and compatible resources. 用于包存储、快照与兼容资源的规范 LuaSkills 数据根。

distribution_root: PathBuf

Canonical read-only root that supplied runtime and package-manager installations. 提供运行时及包管理器安装的规范只读根。

environment_root: PathBuf

Canonical writable root that owns reusable managed environments. 拥有可复用受管环境的规范可写根。

distribution_source: ManagedRuntimeRootSource

Stable source of the selected distribution root. 所选发行根的稳定来源。

environment_source: ManagedRuntimeRootSource

Stable source of the selected environment root. 所选环境根的稳定来源。

runtime_install_root: PathBuf

Canonical runtime installation directory captured by the plan. 计划捕获的规范运行时安装目录。

runtime_version: String

Exact interpreter runtime version. 精确解释器运行时版本。

runtime_executable: PathBuf

Absolute interpreter executable path. 解释器可执行文件绝对路径。

runtime_install_manifest_hash: String

SHA-256 digest of the selected runtime installation manifest. 所选运行时安装清单的 SHA-256 摘要。

runtime_executable_hash: String

SHA-256 digest of the selected runtime executable. 所选运行时可执行文件的 SHA-256 摘要。

package_manager: String

Package manager name such as uv or pnpm. 包管理器名称,例如 uvpnpm

package_manager_version: String

Exact package-manager version. 精确包管理器版本。

package_manager_executable: PathBuf

Absolute package-manager executable path. 包管理器可执行文件绝对路径。

package_manager_install_root: PathBuf

Canonical package-manager installation directory captured by the plan. 计划捕获的规范包管理器安装目录。

package_manager_install_manifest_hash: String

SHA-256 digest of the selected package-manager installation manifest. 所选包管理器安装清单的 SHA-256 摘要。

package_manager_executable_hash: String

SHA-256 digest of the selected package-manager executable. 所选包管理器可执行文件的 SHA-256 摘要。

package_manifest_path: Option<PathBuf>

Optional package manifest path such as package.json. package.json 等可选包清单路径。

lockfile_path: PathBuf

Required lockfile path. 必需的锁文件路径。

lock_hash: String

SHA-256 digest of the dependency lockfile content. 依赖锁文件内容的 SHA-256 摘要。

package_manifest_hash: Option<String>

Optional SHA-256 digest of an additional package manifest such as package.json. package.json 等附加包清单的可选 SHA-256 摘要。

env_hash: String

Environment identity hash. 环境身份哈希。

env_dir: PathBuf

Directory that stores this reusable environment. 保存当前可复用环境的目录。

expected_marker: ManagedRuntimeEnvMarker

Marker expected after environment creation. 环境创建完成后期望写入的标记。