pub struct ManagedRuntimeInstallManifest {
pub schema_version: u32,
pub runtime: String,
pub version: String,
pub platform: String,
pub executable: String,
}Expand description
Manifest written next to each managed runtime or package-manager installation. 写入每个受管运行时或包管理器安装目录旁的清单。
Fields
schema_version: u32Manifest schema version. 清单 schema 版本。
runtime: StringRuntime or package-manager identifier such as python, node, uv, or pnpm.
运行时或包管理器标识,例如 python、node、uv 或 pnpm。
version: StringExact installed version. 已安装的精确版本。
platform: StringPlatform key stored by the installation script. 安装脚本写入的平台键。
executable: StringExecutable path relative to the installation directory. 相对安装目录的可执行文件路径。