pub struct ManagedRuntimePersistentSessionCapability {
pub supported: bool,
pub target_os: String,
pub target_arch: String,
pub reason: Option<String>,
}Expand description
Machine-readable capability for persistent managed Python and Node sessions. 受管 Python 与 Node 持久会话的机器可读能力。
Fields
supported: boolWhether session.open is supported without creating any runtime resources first.
是否可在不预先创建任何运行时资源的情况下支持 session.open。
target_os: StringRust target operating-system identifier for the current binary. 当前二进制的 Rust 目标操作系统标识。
target_arch: StringRust target CPU-architecture identifier for the current binary. 当前二进制的 Rust 目标 CPU 架构标识。
reason: Option<String>Stable unsupported reason code; absent for supported targets. 稳定的不支持原因码;受支持目标上不存在。