pub struct DependencyPackageSpec {
pub archive_type: DependencyArchiveType,
pub asset_name: Option<String>,
pub url: Option<String>,
pub exports: Vec<DependencyExportSpec>,
}Expand description
One platform-specific package record resolved before actual download. 在实际下载前解析得到的单个平台包记录。
Fields
archive_type: DependencyArchiveTypeArchive format of the package payload. 包载荷对应的归档格式。
asset_name: Option<String>Exact GitHub asset file name used for github_release downloads. 用于 github_release 下载的精确 GitHub 资产文件名。
url: Option<String>Exact download URL used for direct url or resolved skilllist packages. 用于直接 url 或已解析 skilllist 包的精确下载地址。
exports: Vec<DependencyExportSpec>Exported files that must be installed and later used for existence checks. 必须被安装、并在之后用于存在性检测的导出文件列表。