Skip to main contentModule logging
Source - RuntimeLogEvent
- Structured runtime log event forwarded from the library to the host callback.
从库转发到宿主回调的结构化运行时日志事件。
- RuntimeLogLevel
- Stable runtime log level emitted by the LuaSkills library.
LuaSkills 库发出的稳定运行时日志级别。
- emit
- Emit one structured runtime log event to the current host callback if it exists.
若当前宿主回调存在,则向其发送一条结构化运行时日志事件。
- error
- Emit one error runtime log event.
发送一条错误级运行时日志事件。
- info
- Emit one informational runtime log event.
发送一条信息级运行时日志事件。
- set_log_callback
- Register or replace the host-side runtime log callback.
注册或替换宿主侧运行时日志回调。
- warn
- Emit one warning runtime log event.
发送一条告警级运行时日志事件。
- RuntimeLogCallback
- Host callback type that receives runtime log events.
接收运行时日志事件的宿主回调类型。